@@ -1,24 +1,25 @@
 /* libiso8601/src/libiso8601/200_parser.c
  *
- *  (c)2006, Laurence Withers, <l@lwithers.me.uk>.
- *  Released under the GNU GPLv2. See file COPYING or
+ *  (c)2006-2010, Laurence Withers, <l@lwithers.me.uk>.
+ *  Released under the GNU GPLv3. See file COPYING or
  *  http://www.gnu.org/copyleft/gpl.html for details.
 */
 
 
 
-int iso8601_parse(const char* str, struct iso8601_date* earliest, struct iso8601_date* latest,
-    struct iso8601_details* details)
+int
+iso8601_parse(const char* str, struct iso8601_date* earliest,
+    struct iso8601_date* latest, struct iso8601_details* details)
 {
     enum {
         state_none,
-        state_year, // e.g. `2006' or `2006123'
-        state_date2, // 2nd component of date, e.g. `2006-' or `2006-1'
-        state_day, // e.g. `2006-01-' or `2006-01-01'
-        state_week_basic, // e.g. `2006W' or `2006W123'
-        state_week_extended, // e.g. `2006-W' or `2006-W31'
-        state_week_day, // e.g. `2006-W31-'
-        state_week_done, // `2006-W31-1'
+        state_year, /* e.g. `2006' or `2006123' */
+        state_date2, /* 2nd component of date, e.g. `2006-' or `2006-1' */
+        state_day, /* e.g. `2006-01-' or `2006-01-01' */
+        state_week_basic, /* e.g. `2006W' or `2006W123' */
+        state_week_extended, /* e.g. `2006-W' or `2006-W31' */
+        state_week_day, /* e.g. `2006-W31-' */
+        state_week_done, /* `2006-W31-1' */
         state_time_basic,
         state_time_hour,
         state_time_min,
@@ -34,8 +35,9 @@ int iso8601_parse(const char* str, struct iso8601_date* earliest, struct iso8601
 
     div_t qr;
     char ch;
-    int num = 0, neg = 0, dig = 0, tz_neg = 0, nsec = -1, nsec_dig = -1, leap_sec_req = 0;
-    int y = 0, m = -1, d = -1, w = -1, wd = -1, hour = -1, min = -1, sec = -1, tz_sec = 0;
+    int num = 0, neg = 0, dig = 0, tz_neg = 0, nsec = -1, nsec_dig = -1,
+        leap_sec_req = 0, y = 0, m = -1, d = -1, w = -1, wd = -1, hour = -1,
+        min = -1, sec = -1, tz_sec = 0;
     double frac;
     struct iso8601_elapsed elapsed;
 
@@ -436,7 +438,8 @@ int iso8601_parse(const char* str, struct iso8601_date* earliest, struct iso8601
             case '-':
                 tz_neg = -1;
             case '+':
-                state = (state == state_time_nsec_basic) ? state_tz_basic : state_tz_hour;
+                state = (state == state_time_nsec_basic) ?
+                    state_tz_basic : state_tz_hour;
                 break;
             }
             break;
@@ -544,7 +547,8 @@ done:
     if(m != -1) {
         if(d == -1) {
             ERROR_IF(earliest && iso8601_from_cal(earliest, y, m, 1));
-            ERROR_IF(latest && iso8601_from_cal(latest, y, m, _days_in_month(y, m)));
+            ERROR_IF(latest && iso8601_from_cal(latest, y, m,
+                _days_in_month(y, m)));
             if(details) details->date_prec = iso8601_prec_month;
 
         } else {
@@ -608,7 +612,8 @@ done:
 
     } else if(min != -1) {
         if(nsec_dig == -1) {
-            ERROR_IF(earliest && iso8601_from_clocktime(earliest, hour, min, 0));
+            ERROR_IF(earliest && iso8601_from_clocktime(earliest,
+                hour, min, 0));
             ERROR_IF(latest && iso8601_from_clocktime(latest, hour, min, 59));
             if(latest) latest->nsec = 999999999;
             if(details) details->time_prec = iso8601_prec_min;
@@ -617,7 +622,8 @@ done:
             frac = nsec * 60.0 / 1e9;
             sec = (int)frac;
             nsec = (frac - sec) * 1e9;
-            ERROR_IF(earliest && iso8601_from_clocktime(earliest, hour, min, sec));
+            ERROR_IF(earliest && iso8601_from_clocktime(earliest,
+                hour, min, sec));
             if(earliest) earliest->nsec = nsec;
             ERROR_IF(latest && iso8601_from_clocktime(latest, hour, min, sec));
             if(latest) latest->nsec = nsec;
@@ -639,7 +645,8 @@ done:
             frac *= 60;
             sec = (int)frac;
             nsec = (frac - sec) * 1e9;
-            ERROR_IF(earliest && iso8601_from_clocktime(earliest, hour, min, sec));
+            ERROR_IF(earliest && iso8601_from_clocktime(earliest,
+                hour, min, sec));
             if(earliest) earliest->nsec = nsec;
             ERROR_IF(latest && iso8601_from_clocktime(latest, hour, min, sec));
             if(latest) latest->nsec = nsec;
@@ -676,7 +683,8 @@ done:
 
 
 
-int iso8601_invalid(const struct iso8601_date* date)
+int
+iso8601_invalid(const struct iso8601_date* date)
 {
     return date->nsec < 0
         || date->nsec >= BILLION
